==> Paws-0.36.tar.gz: Paws-0.36/lib/Paws/CodeStar/DeleteUserProfile.pm <==

package Paws::CodeStar::DeleteUserProfile;
  use Moose;
  has UserArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'userArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteUserProfile');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeStar::DeleteUserProfileResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeStar::DeleteUserProfile - Arguments for method DeleteUserProfile on Paws::CodeStar

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteUserProfile on the 
AWS CodeStar service. Use the attributes of this class
as arguments to method DeleteUserProfile.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteUserProfile.

As an example:

  $service_obj->DeleteUserProfile(Att1 => $value1, Att2 => $value2, ...);

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.

=head1 ATTRIBUTES


=head2 B<REQUIRED> UserArn => Str

The Amazon Resource Name (ARN) of the user to delete from AWS CodeStar.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteUserProfile in L<Paws::CodeStar>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.46.tar.gz: Paws-0.46/lib/Paws/CodeStar/DeleteUserProfile.pm <==

package Paws::CodeStar::DeleteUserProfile;
  use Moose;
  has UserArn => (is => 'ro', isa => 'Str', traits => ['NameInRequest'], request_name => 'userArn' , required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteUserProfile');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::CodeStar::DeleteUserProfileResult');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::CodeStar::DeleteUserProfile - Arguments for method DeleteUserProfile on L<Paws::CodeStar>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteUserProfile on the
L<AWS CodeStar|Paws::CodeStar> service. Use the attributes of this class
as arguments to method DeleteUserProfile.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteUserProfile.

=head1 SYNOPSIS

    my $codestar = Paws->service('CodeStar');
    my $DeleteUserProfileResult = $codestar->DeleteUserProfile(
      UserArn => 'MyUserArn',

    );

    # Results:
    my $UserArn = $DeleteUserProfileResult->UserArn;

    # Returns a L<Paws::CodeStar::DeleteUserProfileResult> object.

Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/codestar/DeleteUserProfile>

=head1 ATTRIBUTES


=head2 B<REQUIRED> UserArn => Str

The Amazon Resource Name (ARN) of the user to delete from AWS CodeStar.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteUserProfile in L<Paws::CodeStar>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
